#!/usr/bin/env python
"""
Filter for KickAssembler output to GCC compatible
Author: Roman 'gryf' Dobosz
Licence: Beerware :) (See desc on https://en.wikipedia.org/wiki/Beerware)
"""

import sys
import re

re_carret = re.compile("^\s+\^$")
re_msg = re.compile("^[a-zA-Z].+$")
re_coord = re.compile("^at line (\d+), column (\d+) in (.+)$")
in_err = None
line_no = 0
column = 0
msg = ''
filename = ''
errors = []

while True:
    line = sys.stdin.readline()

    if not line:
        break

    line = line.rstrip()
    # uncomment to get all the output
    #print line

    if re_carret.search(line):
        in_err = {}
        continue

    if in_err is not None and re_coord.match(line):
        line_no, column, filename = re_coord.match(line).groups()
        in_err.update({'l': line_no, 'c': column, 'f': filename })
        errors.append(in_err)
        in_err = None
        continue

    # most greedy pattern
    if in_err is not None and re_msg.match(line):
        in_err['msg'] = line
        continue

if errors:
    for item in errors:
        print "%(f)s:%(l)s:%(c)s: %(msg)s" % item
    sys.exit(1)

sys.exit(0)
